@@ -100,6 +100,17 @@ class ArcReturnJSONObject:
         except Exception as e:
             log.debug(e.args)
 
+    def get_result(self):
+        return self.dict['result']
+
+    def get_message(self):
+        return self.dict['message']
+
+    def get_data(self):
+        return self.dict['data']
+
+
+
 
 
 # class ArcImage:
